@@ -26,6 +26,7 @@ class ApplicationListModel : public QAbstractListModel
 public:
     enum Roles {
         DelegateRole = Qt::UserRole + 1,
+        NameRole,
     };
 
     ApplicationListModel(HomeScreen *parent = nullptr);
@@ -40,10 +41,15 @@ public:
 public Q_SLOTS:
     void sycocaDbChanged();
 
-Q_SIGNALS:
-    void launchError(const QString &msg);
-
 protected:
     HomeScreen *m_homeScreen{nullptr};
     QList<FolioDelegate *> m_delegates;
 };
+
+class ApplicationListSearchModel : public QSortFilterProxyModel
+{
+    Q_OBJECT
+
+public:
+    ApplicationListSearchModel(HomeScreen *parent = nullptr, ApplicationListModel *model = nullptr);
+};
